aboutsummaryrefslogtreecommitdiffstats
path: root/addon/randplace
diff options
context:
space:
mode:
authorFriendika <info@friendika.com>2010-12-24 23:44:17 -0800
committerFriendika <info@friendika.com>2010-12-24 23:44:17 -0800
commitd045fd04d4b42a749a113dd27f439f9766800975 (patch)
tree78ab3b0ecaea1695249fe862bf051d1d616937dc /addon/randplace
parent6891d44e0b765d230bd3b483c5e283647947c4cb (diff)
downloadvolse-hubzilla-d045fd04d4b42a749a113dd27f439f9766800975.tar.gz
volse-hubzilla-d045fd04d4b42a749a113dd27f439f9766800975.tar.bz2
volse-hubzilla-d045fd04d4b42a749a113dd27f439f9766800975.zip
provide separate plugin settings page, update demo plugin, fix hook_register
Diffstat (limited to 'addon/randplace')
-rw-r--r--addon/randplace/randplace.php14
1 files changed, 7 insertions, 7 deletions
diff --git a/addon/randplace/randplace.php b/addon/randplace/randplace.php
index e14ae74c7..6203dab8f 100644
--- a/addon/randplace/randplace.php
+++ b/addon/randplace/randplace.php
@@ -36,13 +36,13 @@ function randplace_install() {
/**
*
* Then we'll attach into the settings page, on both the
* form and post hooks so that we can create and update
* user preferences.
*
*/
- register_hook('settings_form', 'addon/randplace/randplace.php', 'randplace_settings');
+ register_hook('plugin_settings', 'addon/randplace/randplace.php', 'randplace_settings');
register_hook('settings_post', 'addon/randplace/randplace.php', 'randplace_settings_post');
logger("installed randplace");
@@ -60,7 +60,7 @@ function randplace_uninstall() {
*/
unregister_hook('post_local', 'addon/randplace/randplace.php', 'randplace_post_hook');
- unregister_hook('settings_form', 'addon/randplace/randplace.php', 'randplace_settings');
+ unregister_hook('plugin_settings', 'addon/randplace/randplace.php', 'randplace_settings');
unregister_hook('settings_post', 'addon/randplace/randplace.php', 'randplace_settings_post');
@@ -154,7 +154,7 @@ function randplace_settings(&$a,&$s) {
if(! local_user())
return;
- /* Add our stylesheet so we can match the page layout */
+ /* Add our stylesheet so we can make our settings look nice */
$a->page['htmlhead'] .= '<link rel="stylesheet" type="text/css" href="' . $a->get_baseurl() . '/addon/randplace/randplace.css' . '" media="all" />' . "\r\n";
@@ -164,7 +164,7 @@ function randplace_settings(&$a,&$s) {
$checked = (($enabled) ? ' checked="checked" ' : '');
- /* Add some HTML to the form */
+ /* Add some HTML to the existing form */
$s .= '<h3>' . t('Randplace Settings') . '</h3>';
$s .= '<div id="randplace-enable-wrapper">';
@@ -172,7 +172,7 @@ function randplace_settings(&$a,&$s) {
$s .= '<input id="randplace-checkbox" type="checkbox" name="randplace" value="1" ' . $checked . '/>';
$s .= '</div><div class="clear"></div>';
- /* provide another submit button */
+ /* provide a submit button */
$s .= '<div class="settings-submit-wrapper" ><input type="submit" name="submit" class="settings-submit" value="' . t('Submit') . '" /></div>';
@@ -36,13 +36,13 @@ function randplace_install() {
/**
*
- * Then we'll attach into the settings page, on both the
- * form and post hooks so that we can create and update
+ * Then we'll attach into the plugin settings page, and also the
+ * settings post hooks so that we can create and update
* user preferences.
*